models

package
v2.0.0+incompatible Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 8, 2018 License: Apache-2.0 Imports: 6 Imported by: 0

Documentation

Index

Constants

const (
	// DeploymentStatusTodeploy captures enum value "todeploy"
	DeploymentStatusTodeploy string = "todeploy"
	// DeploymentStatusScheduled captures enum value "scheduled"
	DeploymentStatusScheduled string = "scheduled"
	// DeploymentStatusDeployed captures enum value "deployed"
	DeploymentStatusDeployed string = "deployed"
	// DeploymentStatusFailed captures enum value "failed"
	DeploymentStatusFailed string = "failed"
	// DeploymentStatusToundeploy captures enum value "toundeploy"
	DeploymentStatusToundeploy string = "toundeploy"
	// DeploymentStatusUndeployed captures enum value "undeployed"
	DeploymentStatusUndeployed string = "undeployed"
)
const (
	// RelationshipStatusUp captures enum value "up"
	RelationshipStatusUp string = "up"
	// RelationshipStatusDown captures enum value "down"
	RelationshipStatusDown string = "down"
)

Variables

This section is empty.

Functions

This section is empty.

Types

type Application

type Application struct {

	// description
	Description string `json:"description,omitempty"`

	// Unique id retrieved by the monitor from the underlying PaaS system (k8s)
	ID string `json:"id,omitempty"`

	// microservices
	Microservices ApplicationMicroservices `json:"microservices,omitempty"`

	// Unique FogAtlas internal name, defined by the user in a deployment request
	Name string `json:"name,omitempty"`

	// status
	Status string `json:"status,omitempty"`
}

Application application swagger:model Application

func (*Application) MarshalBinary

func (m *Application) MarshalBinary() ([]byte, error)

MarshalBinary interface implementation

func (*Application) UnmarshalBinary

func (m *Application) UnmarshalBinary(b []byte) error

UnmarshalBinary interface implementation

func (*Application) Validate

func (m *Application) Validate(formats strfmt.Registry) error

Validate validates this application

type ApplicationMicroservices

type ApplicationMicroservices []*ApplicationMicroservicesItems

ApplicationMicroservices application microservices swagger:model applicationMicroservices

func (ApplicationMicroservices) Validate

func (m ApplicationMicroservices) Validate(formats strfmt.Registry) error

Validate validates this application microservices

type ApplicationMicroservicesItems

type ApplicationMicroservicesItems struct {

	// microservice id
	MicroserviceID string `json:"microservice_id,omitempty"`
}

ApplicationMicroservicesItems application microservices items swagger:model applicationMicroservicesItems

func (*ApplicationMicroservicesItems) MarshalBinary

func (m *ApplicationMicroservicesItems) MarshalBinary() ([]byte, error)

MarshalBinary interface implementation

func (*ApplicationMicroservicesItems) UnmarshalBinary

func (m *ApplicationMicroservicesItems) UnmarshalBinary(b []byte) error

UnmarshalBinary interface implementation

func (*ApplicationMicroservicesItems) Validate

func (m *ApplicationMicroservicesItems) Validate(formats strfmt.Registry) error

Validate validates this application microservices items

type Dataflow

type Dataflow struct {

	// Required amount of bandwidth available on the link - bit/s
	BandwidthRequired int64 `json:"bandwidth_required,omitempty"`

	// destination id
	DestinationID string `json:"destination_id,omitempty"`

	// Required link latency - milliseconds
	LatencyRequired int64 `json:"latency_required,omitempty"`

	// source id
	SourceID string `json:"source_id,omitempty"`
}

Dataflow dataflow swagger:model Dataflow

func (*Dataflow) MarshalBinary

func (m *Dataflow) MarshalBinary() ([]byte, error)

MarshalBinary interface implementation

func (*Dataflow) UnmarshalBinary

func (m *Dataflow) UnmarshalBinary(b []byte) error

UnmarshalBinary interface implementation

func (*Dataflow) Validate

func (m *Dataflow) Validate(formats strfmt.Registry) error

Validate validates this dataflow

type Deployment

type Deployment struct {

	// dataflows
	Dataflows DeploymentDataflows `json:"dataflows,omitempty"`

	// description
	Description string `json:"description,omitempty"`

	// externalendpoint id
	ExternalendpointID string `json:"externalendpoint_id,omitempty"`

	// microservices
	Microservices DeploymentMicroservices `json:"microservices,omitempty"`

	// Unique FogAtlas internal name, defined by the user in a deployment request
	Name string `json:"name,omitempty"`

	// status
	Status string `json:"status,omitempty"`
}

Deployment deployment swagger:model Deployment

func (*Deployment) MarshalBinary

func (m *Deployment) MarshalBinary() ([]byte, error)

MarshalBinary interface implementation

func (*Deployment) UnmarshalBinary

func (m *Deployment) UnmarshalBinary(b []byte) error

UnmarshalBinary interface implementation

func (*Deployment) Validate

func (m *Deployment) Validate(formats strfmt.Registry) error

Validate validates this deployment

type DeploymentDataflows

type DeploymentDataflows []*Dataflow

DeploymentDataflows deployment dataflows swagger:model deploymentDataflows

func (DeploymentDataflows) Validate

func (m DeploymentDataflows) Validate(formats strfmt.Registry) error

Validate validates this deployment dataflows

type DeploymentMicroservices

type DeploymentMicroservices []*MicroserviceRequirements

DeploymentMicroservices deployment microservices swagger:model deploymentMicroservices

func (DeploymentMicroservices) Validate

func (m DeploymentMicroservices) Validate(formats strfmt.Registry) error

Validate validates this deployment microservices

type DynamicNode

type DynamicNode struct {

	// id
	ID string `json:"id,omitempty"`

	// ip address
	IPAddress string `json:"ip_address,omitempty"`

	// Id of the corresponding node in the cluster
	NodeID string `json:"node_id,omitempty"`

	// region id
	RegionID string `json:"region_id,omitempty"`
}

DynamicNode Represent a bare metal node that can be commissioned (join the cluster) and decommissioned swagger:model DynamicNode

func (*DynamicNode) MarshalBinary

func (m *DynamicNode) MarshalBinary() ([]byte, error)

MarshalBinary interface implementation

func (*DynamicNode) UnmarshalBinary

func (m *DynamicNode) UnmarshalBinary(b []byte) error

UnmarshalBinary interface implementation

func (*DynamicNode) Validate

func (m *DynamicNode) Validate(formats strfmt.Registry) error

Validate validates this dynamic node

type ExternalEndpoint

type ExternalEndpoint struct {

	// description
	Description string `json:"description,omitempty"`

	// id
	ID string `json:"id,omitempty"`

	// ip address
	IPAddress string `json:"ip_address,omitempty"`

	// location
	Location string `json:"location,omitempty"`

	// name
	Name string `json:"name,omitempty"`

	// region id
	RegionID string `json:"region_id,omitempty"`

	// type
	Type string `json:"type,omitempty"`
}

ExternalEndpoint external endpoint swagger:model ExternalEndpoint

func (*ExternalEndpoint) MarshalBinary

func (m *ExternalEndpoint) MarshalBinary() ([]byte, error)

MarshalBinary interface implementation

func (*ExternalEndpoint) UnmarshalBinary

func (m *ExternalEndpoint) UnmarshalBinary(b []byte) error

UnmarshalBinary interface implementation

func (*ExternalEndpoint) Validate

func (m *ExternalEndpoint) Validate(formats strfmt.Registry) error

Validate validates this external endpoint

type GetApplicationsOKBody

type GetApplicationsOKBody struct {

	// applications
	Applications GetApplicationsOKBodyApplications `json:"applications"`
}

GetApplicationsOKBody get applications o k body swagger:model getApplicationsOKBody

func (*GetApplicationsOKBody) MarshalBinary

func (m *GetApplicationsOKBody) MarshalBinary() ([]byte, error)

MarshalBinary interface implementation

func (*GetApplicationsOKBody) UnmarshalBinary

func (m *GetApplicationsOKBody) UnmarshalBinary(b []byte) error

UnmarshalBinary interface implementation

func (*GetApplicationsOKBody) Validate

func (m *GetApplicationsOKBody) Validate(formats strfmt.Registry) error

Validate validates this get applications o k body

type GetApplicationsOKBodyApplications

type GetApplicationsOKBodyApplications []*Application

GetApplicationsOKBodyApplications get applications o k body applications swagger:model getApplicationsOKBodyApplications

func (GetApplicationsOKBodyApplications) Validate

Validate validates this get applications o k body applications

type GetDataflowsOKBody

type GetDataflowsOKBody struct {

	// dataflows
	Dataflows GetDataflowsOKBodyDataflows `json:"dataflows"`
}

GetDataflowsOKBody get dataflows o k body swagger:model getDataflowsOKBody

func (*GetDataflowsOKBody) MarshalBinary

func (m *GetDataflowsOKBody) MarshalBinary() ([]byte, error)

MarshalBinary interface implementation

func (*GetDataflowsOKBody) UnmarshalBinary

func (m *GetDataflowsOKBody) UnmarshalBinary(b []byte) error

UnmarshalBinary interface implementation

func (*GetDataflowsOKBody) Validate

func (m *GetDataflowsOKBody) Validate(formats strfmt.Registry) error

Validate validates this get dataflows o k body

type GetDataflowsOKBodyDataflows

type GetDataflowsOKBodyDataflows []*Dataflow

GetDataflowsOKBodyDataflows get dataflows o k body dataflows swagger:model getDataflowsOKBodyDataflows

func (GetDataflowsOKBodyDataflows) Validate

func (m GetDataflowsOKBodyDataflows) Validate(formats strfmt.Registry) error

Validate validates this get dataflows o k body dataflows

type GetDeploymentsOKBody

type GetDeploymentsOKBody struct {

	// deployments
	Deployments GetDeploymentsOKBodyDeployments `json:"deployments"`
}

GetDeploymentsOKBody get deployments o k body swagger:model getDeploymentsOKBody

func (*GetDeploymentsOKBody) MarshalBinary

func (m *GetDeploymentsOKBody) MarshalBinary() ([]byte, error)

MarshalBinary interface implementation

func (*GetDeploymentsOKBody) UnmarshalBinary

func (m *GetDeploymentsOKBody) UnmarshalBinary(b []byte) error

UnmarshalBinary interface implementation

func (*GetDeploymentsOKBody) Validate

func (m *GetDeploymentsOKBody) Validate(formats strfmt.Registry) error

Validate validates this get deployments o k body

type GetDeploymentsOKBodyDeployments

type GetDeploymentsOKBodyDeployments []*Deployment

GetDeploymentsOKBodyDeployments get deployments o k body deployments swagger:model getDeploymentsOKBodyDeployments

func (GetDeploymentsOKBodyDeployments) Validate

Validate validates this get deployments o k body deployments

type GetDynamicnodesOKBody

type GetDynamicnodesOKBody struct {

	// dynamicnodes
	Dynamicnodes GetDynamicnodesOKBodyDynamicnodes `json:"dynamicnodes"`
}

GetDynamicnodesOKBody get dynamicnodes o k body swagger:model getDynamicnodesOKBody

func (*GetDynamicnodesOKBody) MarshalBinary

func (m *GetDynamicnodesOKBody) MarshalBinary() ([]byte, error)

MarshalBinary interface implementation

func (*GetDynamicnodesOKBody) UnmarshalBinary

func (m *GetDynamicnodesOKBody) UnmarshalBinary(b []byte) error

UnmarshalBinary interface implementation

func (*GetDynamicnodesOKBody) Validate

func (m *GetDynamicnodesOKBody) Validate(formats strfmt.Registry) error

Validate validates this get dynamicnodes o k body

type GetDynamicnodesOKBodyDynamicnodes

type GetDynamicnodesOKBodyDynamicnodes []*DynamicNode

GetDynamicnodesOKBodyDynamicnodes get dynamicnodes o k body dynamicnodes swagger:model getDynamicnodesOKBodyDynamicnodes

func (GetDynamicnodesOKBodyDynamicnodes) Validate

Validate validates this get dynamicnodes o k body dynamicnodes

type GetExternalendpointsOKBody

type GetExternalendpointsOKBody struct {

	// externalendpoints
	Externalendpoints GetExternalendpointsOKBodyExternalendpoints `json:"externalendpoints"`
}

GetExternalendpointsOKBody get externalendpoints o k body swagger:model getExternalendpointsOKBody

func (*GetExternalendpointsOKBody) MarshalBinary

func (m *GetExternalendpointsOKBody) MarshalBinary() ([]byte, error)

MarshalBinary interface implementation

func (*GetExternalendpointsOKBody) UnmarshalBinary

func (m *GetExternalendpointsOKBody) UnmarshalBinary(b []byte) error

UnmarshalBinary interface implementation

func (*GetExternalendpointsOKBody) Validate

func (m *GetExternalendpointsOKBody) Validate(formats strfmt.Registry) error

Validate validates this get externalendpoints o k body

type GetExternalendpointsOKBodyExternalendpoints

type GetExternalendpointsOKBodyExternalendpoints []*ExternalEndpoint

GetExternalendpointsOKBodyExternalendpoints get externalendpoints o k body externalendpoints swagger:model getExternalendpointsOKBodyExternalendpoints

func (GetExternalendpointsOKBodyExternalendpoints) Validate

Validate validates this get externalendpoints o k body externalendpoints

type GetMicroservicesOKBody

type GetMicroservicesOKBody struct {

	// microservices
	Microservices GetMicroservicesOKBodyMicroservices `json:"microservices"`
}

GetMicroservicesOKBody get microservices o k body swagger:model getMicroservicesOKBody

func (*GetMicroservicesOKBody) MarshalBinary

func (m *GetMicroservicesOKBody) MarshalBinary() ([]byte, error)

MarshalBinary interface implementation

func (*GetMicroservicesOKBody) UnmarshalBinary

func (m *GetMicroservicesOKBody) UnmarshalBinary(b []byte) error

UnmarshalBinary interface implementation

func (*GetMicroservicesOKBody) Validate

func (m *GetMicroservicesOKBody) Validate(formats strfmt.Registry) error

Validate validates this get microservices o k body

type GetMicroservicesOKBodyMicroservices

type GetMicroservicesOKBodyMicroservices []*Microservice

GetMicroservicesOKBodyMicroservices get microservices o k body microservices swagger:model getMicroservicesOKBodyMicroservices

func (GetMicroservicesOKBodyMicroservices) Validate

Validate validates this get microservices o k body microservices

type GetNodesOKBody

type GetNodesOKBody struct {

	// nodes
	Nodes GetNodesOKBodyNodes `json:"nodes"`
}

GetNodesOKBody get nodes o k body swagger:model getNodesOKBody

func (*GetNodesOKBody) MarshalBinary

func (m *GetNodesOKBody) MarshalBinary() ([]byte, error)

MarshalBinary interface implementation

func (*GetNodesOKBody) UnmarshalBinary

func (m *GetNodesOKBody) UnmarshalBinary(b []byte) error

UnmarshalBinary interface implementation

func (*GetNodesOKBody) Validate

func (m *GetNodesOKBody) Validate(formats strfmt.Registry) error

Validate validates this get nodes o k body

type GetNodesOKBodyNodes

type GetNodesOKBodyNodes []*Node

GetNodesOKBodyNodes get nodes o k body nodes swagger:model getNodesOKBodyNodes

func (GetNodesOKBodyNodes) Validate

func (m GetNodesOKBodyNodes) Validate(formats strfmt.Registry) error

Validate validates this get nodes o k body nodes

type GetRegionsOKBody

type GetRegionsOKBody struct {

	// regions
	Regions GetRegionsOKBodyRegions `json:"regions"`
}

GetRegionsOKBody get regions o k body swagger:model getRegionsOKBody

func (*GetRegionsOKBody) MarshalBinary

func (m *GetRegionsOKBody) MarshalBinary() ([]byte, error)

MarshalBinary interface implementation

func (*GetRegionsOKBody) UnmarshalBinary

func (m *GetRegionsOKBody) UnmarshalBinary(b []byte) error

UnmarshalBinary interface implementation

func (*GetRegionsOKBody) Validate

func (m *GetRegionsOKBody) Validate(formats strfmt.Registry) error

Validate validates this get regions o k body

type GetRegionsOKBodyRegions

type GetRegionsOKBodyRegions []*Region

GetRegionsOKBodyRegions get regions o k body regions swagger:model getRegionsOKBodyRegions

func (GetRegionsOKBodyRegions) Validate

func (m GetRegionsOKBodyRegions) Validate(formats strfmt.Registry) error

Validate validates this get regions o k body regions

type GetRelationshipsOKBody

type GetRelationshipsOKBody struct {

	// relationships
	Relationships GetRelationshipsOKBodyRelationships `json:"relationships"`
}

GetRelationshipsOKBody get relationships o k body swagger:model getRelationshipsOKBody

func (*GetRelationshipsOKBody) MarshalBinary

func (m *GetRelationshipsOKBody) MarshalBinary() ([]byte, error)

MarshalBinary interface implementation

func (*GetRelationshipsOKBody) UnmarshalBinary

func (m *GetRelationshipsOKBody) UnmarshalBinary(b []byte) error

UnmarshalBinary interface implementation

func (*GetRelationshipsOKBody) Validate

func (m *GetRelationshipsOKBody) Validate(formats strfmt.Registry) error

Validate validates this get relationships o k body

type GetRelationshipsOKBodyRelationships

type GetRelationshipsOKBodyRelationships []*Relationship

GetRelationshipsOKBodyRelationships get relationships o k body relationships swagger:model getRelationshipsOKBodyRelationships

func (GetRelationshipsOKBodyRelationships) Validate

Validate validates this get relationships o k body relationships

type GetThingsOKBody

type GetThingsOKBody struct {

	// things
	Things GetThingsOKBodyThings `json:"things"`
}

GetThingsOKBody get things o k body swagger:model getThingsOKBody

func (*GetThingsOKBody) MarshalBinary

func (m *GetThingsOKBody) MarshalBinary() ([]byte, error)

MarshalBinary interface implementation

func (*GetThingsOKBody) UnmarshalBinary

func (m *GetThingsOKBody) UnmarshalBinary(b []byte) error

UnmarshalBinary interface implementation

func (*GetThingsOKBody) Validate

func (m *GetThingsOKBody) Validate(formats strfmt.Registry) error

Validate validates this get things o k body

type GetThingsOKBodyThings

type GetThingsOKBodyThings []*Thing

GetThingsOKBodyThings get things o k body things swagger:model getThingsOKBodyThings

func (GetThingsOKBodyThings) Validate

func (m GetThingsOKBodyThings) Validate(formats strfmt.Registry) error

Validate validates this get things o k body things

type Message

type Message struct {

	// message
	Message string `json:"message,omitempty"`
}

Message message swagger:model Message

func (*Message) MarshalBinary

func (m *Message) MarshalBinary() ([]byte, error)

MarshalBinary interface implementation

func (*Message) UnmarshalBinary

func (m *Message) UnmarshalBinary(b []byte) error

UnmarshalBinary interface implementation

func (*Message) Validate

func (m *Message) Validate(formats strfmt.Registry) error

Validate validates this message

type Microservice

type Microservice struct {

	// application id
	ApplicationID string `json:"application_id,omitempty"`

	// description
	Description string `json:"description,omitempty"`

	// Unique id retrieved by the monitor from the underlying PaaS system (k8s)
	ID string `json:"id,omitempty"`

	// Unique FogAtlas internal name, defined by the user in a deployment request
	Name string `json:"name,omitempty"`

	// node id
	NodeID string `json:"node_id,omitempty"`

	// region id
	RegionID string `json:"region_id,omitempty"`

	// status
	Status string `json:"status,omitempty"`
}

Microservice microservice swagger:model Microservice

func (*Microservice) MarshalBinary

func (m *Microservice) MarshalBinary() ([]byte, error)

MarshalBinary interface implementation

func (*Microservice) UnmarshalBinary

func (m *Microservice) UnmarshalBinary(b []byte) error

UnmarshalBinary interface implementation

func (*Microservice) Validate

func (m *Microservice) Validate(formats strfmt.Registry) error

Validate validates this microservice

type MicroserviceRequirements

type MicroserviceRequirements struct {

	// cpu required
	CPURequired string `json:"cpu_required,omitempty"`

	// deployment descriptor
	DeploymentDescriptor string `json:"deployment_descriptor,omitempty"`

	// description
	Description string `json:"description,omitempty"`

	// disk required
	DiskRequired string `json:"disk_required,omitempty"`

	// memory required
	MemoryRequired string `json:"memory_required,omitempty"`

	// Unique FogAtlas internal name, defined by the user in a deployment request
	Name string `json:"name,omitempty"`

	// The price of this micrservice calculated through the negotiator
	PriceComputed float64 `json:"price_computed,omitempty"`

	// Upper bound limit of the price of this microservice fixed by the user/client. -1 means not set
	PriceRequired float64 `json:"price_required,omitempty"`

	// region id
	RegionID string `json:"region_id,omitempty"`

	// region required
	RegionRequired string `json:"region_required,omitempty"`
}

MicroserviceRequirements microservice requirements swagger:model MicroserviceRequirements

func (*MicroserviceRequirements) MarshalBinary

func (m *MicroserviceRequirements) MarshalBinary() ([]byte, error)

MarshalBinary interface implementation

func (*MicroserviceRequirements) UnmarshalBinary

func (m *MicroserviceRequirements) UnmarshalBinary(b []byte) error

UnmarshalBinary interface implementation

func (*MicroserviceRequirements) Validate

func (m *MicroserviceRequirements) Validate(formats strfmt.Registry) error

Validate validates this microservice requirements

type Node

type Node struct {

	// architecture
	Architecture string `json:"architecture,omitempty"`

	// cpu available
	CPUAvailable string `json:"cpu_available,omitempty"`

	// cpu capacity
	CPUCapacity string `json:"cpu_capacity,omitempty"`

	// disk available
	DiskAvailable string `json:"disk_available,omitempty"`

	// disk capacity
	DiskCapacity string `json:"disk_capacity,omitempty"`

	// distribution
	Distribution string `json:"distribution,omitempty"`

	// id
	ID string `json:"id,omitempty"`

	// memory available
	MemoryAvailable string `json:"memory_available,omitempty"`

	// memory capacity
	MemoryCapacity string `json:"memory_capacity,omitempty"`

	// region id
	RegionID string `json:"region_id,omitempty"`

	// status
	Status string `json:"status,omitempty"`

	// version
	Version string `json:"version,omitempty"`
}

Node node swagger:model Node

func (*Node) MarshalBinary

func (m *Node) MarshalBinary() ([]byte, error)

MarshalBinary interface implementation

func (*Node) UnmarshalBinary

func (m *Node) UnmarshalBinary(b []byte) error

UnmarshalBinary interface implementation

func (*Node) Validate

func (m *Node) Validate(formats strfmt.Registry) error

Validate validates this node

type PatchStatus

type PatchStatus struct {

	// status
	Status string `json:"status,omitempty"`
}

PatchStatus patch status swagger:model PatchStatus

func (*PatchStatus) MarshalBinary

func (m *PatchStatus) MarshalBinary() ([]byte, error)

MarshalBinary interface implementation

func (*PatchStatus) UnmarshalBinary

func (m *PatchStatus) UnmarshalBinary(b []byte) error

UnmarshalBinary interface implementation

func (*PatchStatus) Validate

func (m *PatchStatus) Validate(formats strfmt.Registry) error

Validate validates this patch status

type Price

type Price struct {

	// max price
	MaxPrice float64 `json:"max_price,omitempty"`

	// min price
	MinPrice float64 `json:"min_price,omitempty"`

	// scarcity
	Scarcity float64 `json:"scarcity,omitempty"`

	// unit price
	UnitPrice float64 `json:"unit_price,omitempty"`
}

Price price swagger:model Price

func (*Price) MarshalBinary

func (m *Price) MarshalBinary() ([]byte, error)

MarshalBinary interface implementation

func (*Price) UnmarshalBinary

func (m *Price) UnmarshalBinary(b []byte) error

UnmarshalBinary interface implementation

func (*Price) Validate

func (m *Price) Validate(formats strfmt.Registry) error

Validate validates this price

type Region

type Region struct {

	// description
	Description string `json:"description,omitempty"`

	// id
	ID string `json:"id,omitempty"`

	// location
	Location string `json:"location,omitempty"`

	// prices
	Prices *RegionPrices `json:"prices,omitempty"`

	// relationships
	Relationships RegionRelationships `json:"relationships,omitempty"`

	// From 0 to X, where 0 is cloud and X is the leaf tier in the hierarchy
	Tier int64 `json:"tier,omitempty"`
}

Region region swagger:model Region

func (*Region) MarshalBinary

func (m *Region) MarshalBinary() ([]byte, error)

MarshalBinary interface implementation

func (*Region) UnmarshalBinary

func (m *Region) UnmarshalBinary(b []byte) error

UnmarshalBinary interface implementation

func (*Region) Validate

func (m *Region) Validate(formats strfmt.Registry) error

Validate validates this region

type RegionPrices

type RegionPrices struct {

	// cpu
	CPU *Price `json:"cpu,omitempty"`

	// disk
	Disk *Price `json:"disk,omitempty"`

	// memory
	Memory *Price `json:"memory,omitempty"`
}

RegionPrices region prices swagger:model regionPrices

func (*RegionPrices) MarshalBinary

func (m *RegionPrices) MarshalBinary() ([]byte, error)

MarshalBinary interface implementation

func (*RegionPrices) UnmarshalBinary

func (m *RegionPrices) UnmarshalBinary(b []byte) error

UnmarshalBinary interface implementation

func (*RegionPrices) Validate

func (m *RegionPrices) Validate(formats strfmt.Registry) error

Validate validates this region prices

type RegionRelationships

type RegionRelationships []*RegionRelationshipsItems

RegionRelationships region relationships swagger:model regionRelationships

func (RegionRelationships) Validate

func (m RegionRelationships) Validate(formats strfmt.Registry) error

Validate validates this region relationships

type RegionRelationshipsItems

type RegionRelationshipsItems struct {

	// relationship id
	RelationshipID string `json:"relationship_id,omitempty"`
}

RegionRelationshipsItems region relationships items swagger:model regionRelationshipsItems

func (*RegionRelationshipsItems) MarshalBinary

func (m *RegionRelationshipsItems) MarshalBinary() ([]byte, error)

MarshalBinary interface implementation

func (*RegionRelationshipsItems) UnmarshalBinary

func (m *RegionRelationshipsItems) UnmarshalBinary(b []byte) error

UnmarshalBinary interface implementation

func (*RegionRelationshipsItems) Validate

func (m *RegionRelationshipsItems) Validate(formats strfmt.Registry) error

Validate validates this region relationships items

type Relationship

type Relationship struct {

	// Amount of bandwidth available on the link - bit/s
	BandwidthAvailable int64 `json:"bandwidth_available,omitempty"`

	// Amount of bandwidth capacity on the link - bit/s
	BandwidthCapacity int64 `json:"bandwidth_capacity,omitempty"`

	// endpoint a
	EndpointA string `json:"endpoint_a,omitempty"`

	// endpoint b
	EndpointB string `json:"endpoint_b,omitempty"`

	// id
	ID string `json:"id,omitempty"`

	// Link latency - milliseconds
	Latency int64 `json:"latency,omitempty"`

	// prices
	Prices *RelationshipPrices `json:"prices,omitempty"`

	// region id
	RegionID string `json:"region_id,omitempty"`

	// status
	Status string `json:"status,omitempty"`
}

Relationship relationship swagger:model Relationship

func (*Relationship) MarshalBinary

func (m *Relationship) MarshalBinary() ([]byte, error)

MarshalBinary interface implementation

func (*Relationship) UnmarshalBinary

func (m *Relationship) UnmarshalBinary(b []byte) error

UnmarshalBinary interface implementation

func (*Relationship) Validate

func (m *Relationship) Validate(formats strfmt.Registry) error

Validate validates this relationship

type RelationshipPrices

type RelationshipPrices struct {

	// bandwidth
	Bandwidth *Price `json:"bandwidth,omitempty"`

	// latency
	Latency *Price `json:"latency,omitempty"`
}

RelationshipPrices relationship prices swagger:model relationshipPrices

func (*RelationshipPrices) MarshalBinary

func (m *RelationshipPrices) MarshalBinary() ([]byte, error)

MarshalBinary interface implementation

func (*RelationshipPrices) UnmarshalBinary

func (m *RelationshipPrices) UnmarshalBinary(b []byte) error

UnmarshalBinary interface implementation

func (*RelationshipPrices) Validate

func (m *RelationshipPrices) Validate(formats strfmt.Registry) error

Validate validates this relationship prices

type Thing

type Thing struct {

	// description
	Description string `json:"description,omitempty"`

	// id
	ID string `json:"id,omitempty"`

	// ip address
	IPAddress string `json:"ip_address,omitempty"`

	// location
	Location string `json:"location,omitempty"`

	// name
	Name string `json:"name,omitempty"`

	// region id
	RegionID string `json:"region_id,omitempty"`

	// type
	Type string `json:"type,omitempty"`
}

Thing thing swagger:model Thing

func (*Thing) MarshalBinary

func (m *Thing) MarshalBinary() ([]byte, error)

MarshalBinary interface implementation

func (*Thing) UnmarshalBinary

func (m *Thing) UnmarshalBinary(b []byte) error

UnmarshalBinary interface implementation

func (*Thing) Validate

func (m *Thing) Validate(formats strfmt.Registry) error

Validate validates this thing

Jump to